@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "datadevicemanager.h"
 #include "datadevice.h"
 #include "datasource.h"
@@ -30,7 +16,6 @@ namespace KWayland
 {
 namespace Client
 {
-
 class Q_DECL_HIDDEN DataDeviceManager::Private
 {
 public:
@@ -106,15 +91,17 @@ DataDevice *DataDeviceManager::getDataDevice(Seat *seat, QObject *parent)
     return device;
 }
 
-DataDeviceManager::operator wl_data_device_manager*() const
+DataDeviceManager::operator wl_data_device_manager *() const
 {
     return d->manager;
 }
 
-DataDeviceManager::operator wl_data_device_manager*()
+DataDeviceManager::operator wl_data_device_manager *()
 {
     return d->manager;
 }
 
 }
 }
+
+#include "moc_datadevicemanager.cpp"
