@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2015  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2015 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "fakeinput.h"
 #include "event_queue.h"
 #include "seat.h"
@@ -24,10 +10,7 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include <QPointF>
 #include <QSizeF>
 
-#include <config-kwayland.h>
-#if HAVE_LINUX_INPUT_H
 #include <linux/input.h>
-#endif
 
 #include <wayland-fake-input-client-protocol.h>
 
@@ -35,7 +18,6 @@ namespace KWayland
 {
 namespace Client
 {
-
 class Q_DECL_HIDDEN FakeInput::Private
 {
 public:
@@ -112,7 +94,6 @@ void FakeInput::requestPointerMoveAbsolute(const QPointF &pos)
 
 void FakeInput::Private::sendPointerButtonState(Qt::MouseButton button, quint32 state)
 {
-#if HAVE_LINUX_INPUT_H
     Q_ASSERT(manager.isValid());
     uint32_t b = 0;
     switch (button) {
@@ -131,7 +112,6 @@ void FakeInput::Private::sendPointerButtonState(Qt::MouseButton button, quint32
         return;
     }
     org_kde_kwin_fake_input_button(manager, b, state);
-#endif
 }
 
 void FakeInput::requestPointerButtonPress(Qt::MouseButton button)
@@ -236,16 +216,17 @@ void FakeInput::requestKeyboardKeyRelease(quint32 linuxKey)
     org_kde_kwin_fake_input_keyboard_key(d->manager, linuxKey, WL_KEYBOARD_KEY_STATE_RELEASED);
 }
 
-
-FakeInput::operator org_kde_kwin_fake_input*() const
+FakeInput::operator org_kde_kwin_fake_input *() const
 {
     return d->manager;
 }
 
-FakeInput::operator org_kde_kwin_fake_input*()
+FakeInput::operator org_kde_kwin_fake_input *()
 {
     return d->manager;
 }
 
 }
 }
+
+#include "moc_fakeinput.cpp"
