@@ -9,7 +9,7 @@
 #include <QObject>
 #include <QPointer>
 
-#include <KWayland/Client/kwaylandclient_export.h>
+#include "KWayland/Client/kwaylandclient_export.h"
 
 struct wl_subsurface;
 
